Struct ImageHandle
pub struct ImageHandle {
pub image: RCHandle<SkImage>,
pub bytes: Bytes,
}Expand description
A decoded image shared by reference, ready to be rendered by an image().
Fields
image: RCHandle<SkImage>bytes: BytesBacking data of the SkImage, kept alive for as long as the image is used.
Implementations
impl ImageHandle
impl ImageHandle
pub fn new(image: RCHandle<SkImage>, bytes: Bytes) -> ImageHandle
pub fn from_rgba(
width: u32,
height: u32,
bytes: Bytes,
alpha_type: SkAlphaType,
) -> Option<ImageHandle>
pub fn from_rgba( width: u32, height: u32, bytes: Bytes, alpha_type: SkAlphaType, ) -> Option<ImageHandle>
Build a handle from a raw RGBA8888 pixel buffer, validating its length.